==> TheengsDecoder-1.7.4.tar.gz: TheengsDecoder-1.7.4/src/devices/tracker_json.h <==
const char* _tracker_json_nut = "{\"brand\":\"nut\",\"model\":\"Smart Tracker\",\"model_id\":\"NUT\",\"tag\":\"100f\",\"condition\":[\"name\",\"index\",0,\"nut\",\"&\",\"manufacturerdata\",\"=\",8,\"&\",\"uuid\",\"index\",0,\"180a\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"nut Tracker\"]}}}";
/*R""""(
{
   "brand":"nut",
   "model":"Smart Tracker",
   "model_id":"NUT",
   "tag":"100f",
   "condition":["name", "index", 0, "nut", "&", "manufacturerdata", "=", 8, "&", "uuid", "index", 0, "180a"],
   "properties":{
      "device":{
         "decoder":["static_value", "nut Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_nutale = "{\"brand\":\"nut\",\"model\":\"Smart Tracker\",\"model_id\":\"NUTALE\",\"tag\":\"100f\",\"condition\":[\"name\",\"index\",0,\"nutale\",\"&\",\"servicedata\",\"=\",24,\"&\",\"uuid\",\"index\",0,\"0900\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"nutale Tracker\"]}}}";
/*R""""(
{
   "brand":"nut",
   "model":"Smart Tracker",
   "model_id":"NUTALE",
   "tag":"100f",
   "condition":["name", "index", 0, "nutale", "&", "servicedata", "=", 24, "&", "uuid", "index", 0, "0900"],
   "properties":{
      "device":{
         "decoder":["static_value", "nutale Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_itag = "{\"brand\":\"iTAG\",\"model\":\"Smart Tracker\",\"model_id\":\"ITAG\",\"tag\":\"100f\",\"condition\":[\"name\",\"index\",0,\"iTAG\",\"&\",\"manufacturerdata\",\"=\",8],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"iTAG Tracker\"]}}}";
/*R""""(
{
   "brand":"iTAG",
   "model":"Smart Tracker",
   "model_id":"ITAG",
   "tag":"100f",
   "condition":["name", "index", 0, "iTAG", "&", "manufacturerdata", "=", 8],
   "properties":{
      "device":{
         "decoder":["static_value", "iTAG Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_tagit = "{\"brand\":\"Tag-It\",\"model\":\"Smart Tracker\",\"model_id\":\"TAGIT\",\"tag\":\"100f\",\"condition\":[\"name\",\"index\",0,\"Tag-It\",\"&\",\"manufacturerdata\",\"=\",26],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Tag-It Tracker\"]}}}";
/*R""""(
{
   "brand":"Tag-It",
   "model":"Smart Tracker",
   "model_id":"TAGIT",
   "tag":"100f",
   "condition":["name", "index", 0, "Tag-It", "&", "manufacturerdata", "=", 26],
   "properties":{
      "device":{
         "decoder":["static_value", "Tag-It Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_tile = "{\"brand\":\"Tile\",\"model\":\"Smart Tracker\",\"model_id\":\"TILE\",\"tag\":\"100f\",\"condition\":[\"uuid\",\"index\",0,\"feed\",\"|\",\"uuid\",\"index\",0,\"feec\",\"|\",\"uuid\",\"index\",0,\"fd84\",\"&\",\"no-mfgdata\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Tile Tracker\"]}}}";
/*R""""(
{
   "brand":"Tile",
   "model":"Smart Tracker",
   "model_id":"TILE",
   "tag":"100f",
   "condition":["uuid", "index", 0, "feed", "|", "uuid", "index", 0, "feec", "|", "uuid", "index", 0, "fd84", "&", "no-mfgdata"],
   "properties":{
      "device":{
         "decoder":["static_value", "Tile Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_tilename = "{\"brand\":\"Tile\",\"model\":\"Smart Tracker\",\"model_id\":\"TILE\",\"tag\":\"100f\",\"condition\":[\"name\",\"index\",0,\"Tile\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Tile Tracker\"]}}}";
/*R""""(
{
   "brand":"Tile",
   "model":"Smart Tracker",
   "model_id":"TILE",
   "tag":"100f",
   "condition":["name", "index", 0, "Tile"],
   "properties":{
      "device":{
         "decoder":["static_value", "Tile Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_theengs01 = "{\"brand\":\"Theengs\",\"model\":\"iBeacon Tracker\",\"model_id\":\"TheengsIB01\",\"tag\":\"1009\",\"condition\":[\"manufacturerdata\",\"=\",50,\"index\",0,\"4c000215546865656e67732d69426561636f6e31\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Theengs iBeacon Tracker\"]}}}";
/*R""""(
{
   "brand":"Theengs",
   "model":"iBeacon Tracker",
   "model_id":"TheengsIB01",
   "tag":"1009",
   "condition":["manufacturerdata", "=", 50, "index", 0, "4c000215546865656e67732d69426561636f6e31"],
   "properties":{
      "device":{
         "decoder":["static_value", "Theengs iBeacon Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_theengs02 = "{\"brand\":\"Theengs\",\"model\":\"iBeacon Tracker\",\"model_id\":\"TheengsIB02\",\"tag\":\"1019\",\"condition\":[\"manufacturerdata\",\"=\",50,\"index\",0,\"4c000215546865656e67732d69426561636f6e32\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Theengs iBeacon Tracker\"]}}}";
/*R""""(
{
   "brand":"Theengs",
   "model":"iBeacon Tracker",
   "model_id":"TheengsIB02",
   "tag":"1019",
   "condition":["manufacturerdata", "=", 50, "index", 0, "4c000215546865656e67732d69426561636f6e32"],
   "properties":{
      "device":{
         "decoder":["static_value", "Theengs iBeacon Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_TICWATCHGTH = "{\"brand\":\"Mobvoi\",\"model\":\"TicWatch GTH (Pro)\",\"model_id\":\"TICWATCHGTH\",\"tag\":\"100b\",\"condition\":[\"name\",\"index\",0,\"TicWatch GTH\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"TicWatch GTH (Pro) Tracker\"]}}}";
/*R""""(
{
   "brand":"Mobvoi",
   "model":"TicWatch GTH (Pro)",
   "model_id":"TICWATCHGTH",
   "tag":"100b",
   "condition":["name", "index", 0, "TicWatch GTH"],
   "properties":{
      "device":{
         "decoder":["static_value", "TicWatch GTH (Pro) Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_GTAG = "{\"brand\":\"Gigaset\",\"model\":\"G-Tag\",\"model_id\":\"GTAG\",\"tag\":\"1008\",\"condition\":[\"manufacturerdata\",\"=\",24,\"index\",0,\"800102151234\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Gigaset G-Tag Tracker\"]}}}";
/*R""""(
{
   "brand":"Gigaset",
   "model":"G-Tag",
   "model_id":"GTAG",
   "tag":"1008",
   "condition":["manufacturerdata", "=", 24, "index", 0, "800102151234"],
   "properties":{
      "device":{
         "decoder":["static_value", "Gigaset G-Tag Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_props = "{\"properties\":{\"device\":{\"unit\":\"string\",\"name\":\"tracker device\"}}}";
/*R""""(
{
   "properties":{
      "device":{
         "unit":"string",
         "name":"tracker device"
      }
   }
})"""";*/

==> TheengsDecoder-1.7.7.tar.gz: TheengsDecoder-1.7.7/src/devices/tracker_json.h <==
const char* _tracker_json_nut = "{\"brand\":\"nut\",\"model\":\"Smart Tracker\",\"model_id\":\"NUT\",\"tag\":\"100f\",\"condition\":[\"name\",\"index\",0,\"nut\",\"&\",\"manufacturerdata\",\"=\",8,\"&\",\"uuid\",\"index\",0,\"180a\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"nut Tracker\"]}}}";
/*R""""(
{
   "brand":"nut",
   "model":"Smart Tracker",
   "model_id":"NUT",
   "tag":"100f",
   "condition":["name", "index", 0, "nut", "&", "manufacturerdata", "=", 8, "&", "uuid", "index", 0, "180a"],
   "properties":{
      "device":{
         "decoder":["static_value", "nut Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_nutale = "{\"brand\":\"nut\",\"model\":\"Smart Tracker\",\"model_id\":\"NUTALE\",\"tag\":\"100f\",\"condition\":[\"name\",\"index\",0,\"nutale\",\"&\",\"servicedata\",\"=\",24,\"&\",\"uuid\",\"index\",0,\"0900\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"nutale Tracker\"]}}}";
/*R""""(
{
   "brand":"nut",
   "model":"Smart Tracker",
   "model_id":"NUTALE",
   "tag":"100f",
   "condition":["name", "index", 0, "nutale", "&", "servicedata", "=", 24, "&", "uuid", "index", 0, "0900"],
   "properties":{
      "device":{
         "decoder":["static_value", "nutale Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_itag = "{\"brand\":\"iTAG\",\"model\":\"Smart Tracker\",\"model_id\":\"ITAG\",\"tag\":\"100f\",\"condition\":[\"name\",\"index\",0,\"iTAG\",\"&\",\"manufacturerdata\",\">=\",8],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"iTAG Tracker\"]}}}";
/*R""""(
{
   "brand":"iTAG",
   "model":"Smart Tracker",
   "model_id":"ITAG",
   "tag":"100f",
   "condition":["name", "index", 0, "iTAG", "&", "manufacturerdata", ">=", 8],
   "properties":{
      "device":{
         "decoder":["static_value", "iTAG Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_tagit = "{\"brand\":\"Tag-It\",\"model\":\"Smart Tracker\",\"model_id\":\"TAGIT\",\"tag\":\"100f\",\"condition\":[\"name\",\"index\",0,\"Tag-It\",\"&\",\"manufacturerdata\",\"=\",26],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Tag-It Tracker\"]}}}";
/*R""""(
{
   "brand":"Tag-It",
   "model":"Smart Tracker",
   "model_id":"TAGIT",
   "tag":"100f",
   "condition":["name", "index", 0, "Tag-It", "&", "manufacturerdata", "=", 26],
   "properties":{
      "device":{
         "decoder":["static_value", "Tag-It Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_tile = "{\"brand\":\"Tile\",\"model\":\"Smart Tracker\",\"model_id\":\"TILE\",\"tag\":\"100f\",\"condition\":[\"uuid\",\"index\",0,\"feed\",\"|\",\"uuid\",\"index\",0,\"feec\",\"|\",\"uuid\",\"index\",0,\"fd84\",\"&\",\"no-mfgdata\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Tile Tracker\"]}}}";
/*R""""(
{
   "brand":"Tile",
   "model":"Smart Tracker",
   "model_id":"TILE",
   "tag":"100f",
   "condition":["uuid", "index", 0, "feed", "|", "uuid", "index", 0, "feec", "|", "uuid", "index", 0, "fd84", "&", "no-mfgdata"],
   "properties":{
      "device":{
         "decoder":["static_value", "Tile Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_tilename = "{\"brand\":\"Tile\",\"model\":\"Smart Tracker\",\"model_id\":\"TILE\",\"tag\":\"100f\",\"condition\":[\"name\",\"index\",0,\"Tile\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Tile Tracker\"]}}}";
/*R""""(
{
   "brand":"Tile",
   "model":"Smart Tracker",
   "model_id":"TILE",
   "tag":"100f",
   "condition":["name", "index", 0, "Tile"],
   "properties":{
      "device":{
         "decoder":["static_value", "Tile Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_theengs01 = "{\"brand\":\"Theengs\",\"model\":\"iBeacon Tracker\",\"model_id\":\"TheengsIB01\",\"tag\":\"1009\",\"condition\":[\"manufacturerdata\",\"=\",50,\"index\",0,\"4c000215546865656e67732d69426561636f6e31\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Theengs iBeacon Tracker\"]}}}";
/*R""""(
{
   "brand":"Theengs",
   "model":"iBeacon Tracker",
   "model_id":"TheengsIB01",
   "tag":"1009",
   "condition":["manufacturerdata", "=", 50, "index", 0, "4c000215546865656e67732d69426561636f6e31"],
   "properties":{
      "device":{
         "decoder":["static_value", "Theengs iBeacon Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_theengs02 = "{\"brand\":\"Theengs\",\"model\":\"iBeacon Tracker\",\"model_id\":\"TheengsIB02\",\"tag\":\"1019\",\"condition\":[\"manufacturerdata\",\"=\",50,\"index\",0,\"4c000215546865656e67732d69426561636f6e32\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Theengs iBeacon Tracker\"]}}}";
/*R""""(
{
   "brand":"Theengs",
   "model":"iBeacon Tracker",
   "model_id":"TheengsIB02",
   "tag":"1019",
   "condition":["manufacturerdata", "=", 50, "index", 0, "4c000215546865656e67732d69426561636f6e32"],
   "properties":{
      "device":{
         "decoder":["static_value", "Theengs iBeacon Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_TICWATCHGTH = "{\"brand\":\"Mobvoi\",\"model\":\"TicWatch GTH (Pro)\",\"model_id\":\"TICWATCHGTH\",\"tag\":\"100b\",\"condition\":[\"name\",\"index\",0,\"TicWatch GTH\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"TicWatch GTH (Pro) Tracker\"]}}}";
/*R""""(
{
   "brand":"Mobvoi",
   "model":"TicWatch GTH (Pro)",
   "model_id":"TICWATCHGTH",
   "tag":"100b",
   "condition":["name", "index", 0, "TicWatch GTH"],
   "properties":{
      "device":{
         "decoder":["static_value", "TicWatch GTH (Pro) Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_GTAG = "{\"brand\":\"Gigaset\",\"model\":\"G-Tag\",\"model_id\":\"GTAG\",\"tag\":\"1008\",\"condition\":[\"manufacturerdata\",\"=\",24,\"index\",0,\"800102151234\"],\"properties\":{\"device\":{\"decoder\":[\"static_value\",\"Gigaset G-Tag Tracker\"]}}}";
/*R""""(
{
   "brand":"Gigaset",
   "model":"G-Tag",
   "model_id":"GTAG",
   "tag":"1008",
   "condition":["manufacturerdata", "=", 24, "index", 0, "800102151234"],
   "properties":{
      "device":{
         "decoder":["static_value", "Gigaset G-Tag Tracker"]
      }
   }
})"""";*/

const char* _tracker_json_props = "{\"properties\":{\"device\":{\"unit\":\"string\",\"name\":\"tracker device\"}}}";
/*R""""(
{
   "properties":{
      "device":{
         "unit":"string",
         "name":"tracker device"
      }
   }
})"""";*/
